@@ -55,8 +55,16 @@ def tox_configure(config):
     config.envlist_default = config.envlist = envlist
     verbosity1("overriding envlist with: {}".format(envlist))
 
-    verbosity2("enabling problem matcher")
-    print("::add-matcher::" + get_problem_matcher_file_path())
+    if is_running_on_container():
+        verbosity2(
+            "not enabling problem matcher as tox seems to be running on a container"
+        )
+        # Trying to add a problem matcher from a container without proper host mount can
+        # cause an error like the following:
+        # Unable to process command '::add-matcher::/.../matcher.json' successfully.
+    else:
+        verbosity2("enabling problem matcher")
+        print("::add-matcher::" + get_problem_matcher_file_path())
 
     if not is_log_grouping_enabled(config):
         verbosity2(
@@ -95,6 +103,9 @@ def tox_runtest_post(venv):
 @hookimpl
 def tox_cleanup(session):
     # This hook can be called multiple times especially when using parallel mode
+    if not is_running_on_actions():
+        return
+    verbosity2("disabling problem matcher")
     for owner in get_problem_matcher_owners():
         print("::remove-matcher owner={}::".format(owner))
 
@@ -236,6 +247,21 @@ def is_running_on_actions():
     return os.environ.get("GITHUB_ACTIONS") == "true"
 
 
+def is_running_on_container():
+    # type: () -> bool
+    """Check whether tox is running on a container or not
+
+    Only Linux containers are supported.
+    """
+    cgroup_path = "/proc/1/cgroup"
+    if os.path.exists(cgroup_path):
+        with open(cgroup_path) as f:
+            for line in f:
+                if "containerd" in line:
+                    return True
+    return False
+
+
 def is_log_grouping_enabled(config):
     # type: (Config) -> bool
     """Returns True when the plugin should enable log line grouping
